summaryrefslogtreecommitdiffstats
path: root/kolourpaint/kpviewmanager.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-19 19:03:33 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-19 19:03:33 +0000
commite69e8b1d09fb579316595b4e6a850e717358a8b1 (patch)
treea24fc20865f65772f530d16177520190594ffdd2 /kolourpaint/kpviewmanager.h
parenteecec9afb81fdebb0f22e9da22635874c403f854 (diff)
downloadtdegraphics-e69e8b1d09fb579316595b4e6a850e717358a8b1.tar.gz
tdegraphics-e69e8b1d09fb579316595b4e6a850e717358a8b1.zip
TQt4 port kdegraphics
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegraphics@1237557 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kolourpaint/kpviewmanager.h')
-rw-r--r--kolourpaint/kpviewmanager.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/kolourpaint/kpviewmanager.h b/kolourpaint/kpviewmanager.h
index 9bb6e8b6..db2724ce 100644
--- a/kolourpaint/kpviewmanager.h
+++ b/kolourpaint/kpviewmanager.h
@@ -44,9 +44,10 @@ class kpView;
class kpMainWindow;
class kpTempPixmap;
-class kpViewManager : public QObject
+class kpViewManager : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
kpViewManager (kpMainWindow *mainWindow);
@@ -68,7 +69,7 @@ public:
const kpTempPixmap *tempPixmap () const;
void setTempPixmap (const kpTempPixmap &tempPixmap);
- void invalidateTempPixmap ();
+ void tqinvalidateTempPixmap ();
//
@@ -120,7 +121,7 @@ public:
// View
//
- kpView *viewUnderCursor (bool usingQt = false) const;
+ kpView *viewUnderCursor (bool usingTQt = false) const;
//
// TQWidget::hasMouse() is unreliable:
@@ -156,18 +157,18 @@ public:
//
// This is better than TQWidget::setUpdatesEnabled() because
// restoreQueueUpdates() automatically restores only the regions
- // of the views that need to be repainted, per view.
+ // of the views that need to be tqrepainted, per view.
bool queueUpdates () const;
void setQueueUpdates ();
void restoreQueueUpdates ();
// Controls behaviour of updateViews():
//
// Slow: Let Qt buffer paint events via TQWidget::update().
// Results in less flicker. Paint events are probably merged
// so long-term efficiency is increased at the expense of
// reduced responsiveness (default).
// Fast: Force Qt to redraw immediately. No paint events
// are merged so there is great potential for flicker,
// if used inappropriately. Use this when the redraw
// area is small and KolourPaint's responsiveness is
@@ -156,18 +157,18 @@ public:
// Controls behaviour of updateViews():
//
- // Slow: Let Qt buffer paint events via TQWidget::update().
+ // Slow: Let TQt buffer paint events via TQWidget::update().
// Results in less flicker. Paint events are probably merged
// so long-term efficiency is increased at the expense of
@@ -156,18 +157,18 @@ public:
// so long-term efficiency is increased at the expense of
// reduced responsiveness (default).
- // Fast: Force Qt to redraw immediately. No paint events
+ // Fast: Force TQt to redraw immediately. No paint events
// are merged so there is great potential for flicker,
// if used inappropriately. Use this when the redraw